.. image:: https://img.shields.io/travis/prody/ProDy.svg
   :target: http://travis-ci.org/#!/prody/ProDy

.. image:: https://img.shields.io/pypi/v/ProDy.svg
   :target: https://pypi.org/project/ProDy/

.. image:: https://img.shields.io/github/commit-activity/y/prody/ProDy.svg
   :target: https://github.com/prody/ProDy/commits/master

.. image:: https://img.shields.io/badge/dynamic/json.svg?label=downloads&colorB=&prefix=&suffix=&query=stat&uri=http%3A%2F%2Fprody.csb.pitt.edu%2Fstatistics%2Fstatistics.json
   :target: http://prody.csb.pitt.edu/downloads/

SYNOPSIS
--------

ProDy is a free and open-source Python package for protein structure, dynamics,
and sequence analysis.  It allows for comparative analysis and modeling of
protein structural dynamics and sequence co-evolution.  Fast and flexible ProDy
API is for interactive usage as well as application development.  ProDy also
comes with several analysis applications and a graphical user interface for
visual analysis.


GETTING PRODY
-------------

You can run ProDy on all major platforms.  For download and installation
instructions see:

* http://prody.csb.pitt.edu/downloads


DOCUMENTATION
-------------

* Homepage: http://prody.csb.pitt.edu/

* Tutorials: http://prody.csb.pitt.edu/tutorials

* Reference: http://prody.csb.pitt.edu/manual

* Applications: http://prody.csb.pitt.edu/manual/apps

* NMWiz GUI: http://prody.csb.pitt.edu/nmwiz

* Changes: http://prody.csb.pitt.edu/manual/release


SOURCE CODE
-----------

* Source code: https://github.com/prody/ProDy

* Issue tracker: https://github.com/prody/ProDy/issues


LICENSE
-------

ProDy is available under MIT License. See LICENSE.txt for more details.

Biopython (http://biopython.org/) KDTree and pairwise2 modules are distributed
with ProDy. Biopython is developed by The Biopython Consortium and is available
under the Biopython license (http://www.biopython.org/DIST/LICENSE).

Pyparsing (http://pyparsing.wikispaces.com/) module is distributed with ProDy.
Pyparsing is developed by Paul T. McGuire and is available under the MIT
license (http://www.opensource.org/licenses/mit-license.php).

Argparse module (http://code.google.com/p/argparse/) is distributed with ProDy.
Argparse is developed by Steven J. Bethard and is available under the Python
Software Foundation License.

CEalign module (https://pymolwiki.org/index.php/Cealign_plugin) is distributed 
with ProDy. The original CE method was developed by Ilya Shindyalov and Philip 
Bourne. The Python version which is used by ProDy is developed by Jason Vertrees 
and available under the New BSD license. 

